@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2017 David R. MacIver
+# Most of this work is copyright (C) 2013-2018 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -20,7 +20,6 @@ some source of data.
 
 It verifies your code against a wide range of input and minimizes any
 failing examples it finds.
-
 """
 
 
@@ -28,7 +27,8 @@ from hypothesis._settings import settings, Verbosity, Phase, HealthCheck, \
     unlimited
 from hypothesis.version import __version_info__, __version__
 from hypothesis.control import assume, note, reject, event
-from hypothesis.core import given, find, example, seed
+from hypothesis.core import given, find, example, seed, reproduce_failure, \
+    PrintSettings
 from hypothesis.utils.conventions import infer
 
 
@@ -37,11 +37,13 @@ __all__ = [
     'Verbosity',
     'HealthCheck',
     'Phase',
+    'PrintSettings',
     'assume',
     'reject',
     'seed',
     'given',
     'unlimited',
+    'reproduce_failure',
     'find',
     'example',
     'note',
